==> piwigo-2.1.6.zip: piwigo/language/sr_RS/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Надоградња";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Ова страница предлаже надоградњу базе са Piwigo старе верзије на нову.
Асистент надоградње процењује да тренутно користите <strong>издање %s</strong> (или еквивалентну).";
$lang['Upgrade from version %s to %s'] = "Надоградња са верзије %s на %s";
$lang['Statistics'] = "Статистика";
$lang['total upgrade time'] = "укупно време надоградње";
$lang['total SQL time'] = "укупно SQL време";
$lang['SQL queries'] = "SQL упити";
$lang['Upgrade informations'] = "Информације о надоградњи";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Извршити проверу одржавања у [Администрација>Алати>Одржавање] ако наиђете на неки проблем.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Као меру предострожност, дати додаци су деактивирани. Морате проверити за надоградњу додатака пре него их поново активирате: ";
$lang['Only administrator can run upgrade: please sign in below.'] = "Само администратор може да покрене надоградњу: пријавите се испод.";
$lang['You do not have access rights to run upgrade'] = "Немате приступна права да покренете надоградњу";
$lang['All sub-categories of private categories become private'] = "Све подкатегорије приватних категорија постају приватне";
$lang['User permissions and group permissions have been erased'] = "Корисничке и групне дозволе су обрисане";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Само префиx за повезне сличице и адреса електронске поште уредника интернет страница су сачуване из претходне конфигурације";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'У <i>%s</i>, испред <b>?></b>, уметни:';
?>

==> piwigo-2.2.4.zip: piwigo/language/sr_RS/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Надоградња";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Ова страница предлаже надоградњу базе са Piwigo старе верзије на нову.
Асистент надоградње процењује да тренутно користите <strong>издање %s</strong> (или еквивалентну).";
$lang['Upgrade from version %s to %s'] = "Надоградња са верзије %s на %s";
$lang['Statistics'] = "Статистика";
$lang['total upgrade time'] = "укупно време надоградње";
$lang['total SQL time'] = "укупно SQL време";
$lang['SQL queries'] = "SQL упити";
$lang['Upgrade informations'] = "Информације о надоградњи";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Извршити проверу одржавања у [Администрација>Алати>Одржавање] ако наиђете на неки проблем.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Као меру предострожност, дати додаци су деактивирани. Морате проверити за надоградњу додатака пре него их поново активирате: ";
$lang['Only administrator can run upgrade: please sign in below.'] = "Само администратор може да покрене надоградњу: пријавите се испод.";
$lang['You do not have access rights to run upgrade'] = "Немате приступна права да покренете надоградњу";
$lang['All sub-albums of private albums become private'] = "Све подкатегорије приватних категорија постају приватне";
$lang['User permissions and group permissions have been erased'] = "Корисничке и групне дозволе су обрисане";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Само префиx за повезне сличице и адреса електронске поште уредника интернет страница су сачуване из претходне конфигурације";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'У <i>%s</i>, испред <b>?></b>, уметни:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Као мера предострожности, следеће теме су деактивиране. Ви треба да проверите да ли теме имају унапређење пре него што их поново активирате:'; 
?>
